using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using Drawing;

namespace DrawingHelperExample
{
  /// <summary>
  /// This is the main type for your game
  /// </summary>
  public class Game1 : Microsoft.Xna.Framework.Game
  {
    GraphicsDeviceManager graphics;
    SpriteBatch spriteBatch;

    public Game1()
    {
      graphics = new GraphicsDeviceManager(this);
      graphics.PreferredBackBufferHeight = 800;
      graphics.PreferredBackBufferHeight = 600;

      IsMouseVisible = true;

      Content.RootDirectory = "Content";
    }

    /// <summary>
    /// Allows the game to perform any initialization it needs to before starting to run.
    /// This is where it can query for any required services and load any non-graphic
    /// related content.  Calling base.Initialize will enumerate through any components
    /// and initialize them as well.
    /// </summary>
    protected override void Initialize()
    {
      //IMPORTANT:
      //Initialize your DrawingHelper here.
      DrawingHelper.Initialize(GraphicsDevice);
      // TODO: Add your initialization logic here
      
      base.Initialize();
    }

    /// <summary>
    /// LoadContent will be called once per game and is the place to load
    /// all of your content.
    /// </summary>
    protected override void LoadContent()
    {
      // Create a new SpriteBatch, which can be used to draw textures.
      spriteBatch = new SpriteBatch(GraphicsDevice);

      // TODO: use this.Content to load your game content here
    }

    /// <summary>
    /// UnloadContent will be called once per game and is the place to unload
    /// all content.
    /// </summary>
    protected override void UnloadContent()
    {
      // TODO: Unload any non ContentManager content here
    }

    /// <summary>
    /// Allows the game to run logic such as updating the world,
    /// checking for collisions, gathering input, and playing audio.
    /// </summary>
    /// <param name="gameTime">Provides a snapshot of timing values.</param>
    protected override void Update(GameTime gameTime)
    {
      // Allows the game to exit
      if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
        this.Exit();

      // TODO: Add your update logic here

      base.Update(gameTime);
    }

    /// <summary>
    /// This is called when the game should draw itself.
    /// </summary>
    /// <param name="gameTime">Provides a snapshot of timing values.</param>
    protected override void Draw(GameTime gameTime)
    {
      GraphicsDevice.Clear(Color.CornflowerBlue);

      //Example of how to draw a fast line, no need to call Begin and End
      DrawingHelper.DrawFastLine(new Vector2(100, 100), new Vector2(200, 200), Color.Black);

      //Example of how to draw a line, using Begin and End
      DrawingHelper.Begin(PrimitiveType.LineList);
      DrawingHelper.DrawLine(new Vector2(250, 250), new Vector2(350, 350), Color.Orange);
      DrawingHelper.End();

      //Example of how to draw multiple lines, it is more efficient than using multiple DrawFastLine
      DrawingHelper.Begin(PrimitiveType.LineList);
      for (int i = 0; i < 100; i += 5)
      {
        DrawingHelper.DrawLine(new Vector2(400 + i, 400), new Vector2(500 + i, 500), Color.Red);  
      }
      DrawingHelper.End();

      //Example of how to draw a non-filled Octagon or 8-Gon
      DrawingHelper.DrawNGon(new Vector2(300, 100), 50, 8, Color.Blue, false);

      //Example of how to draw a filled Circle
      DrawingHelper.DrawCircle(new Vector2(500, 100), 50, Color.Green, true);

      //Example of how to draw a Rectangle
      //There are 5 Overloads, use that one that is best for you
      DrawingHelper.DrawRectangle(new Vector2(10, 10), new Vector2(780, 580), Color.Gold, false);

      //Example of how to draw a filled Rectangle
      //There are 5 Overloads, use that one that is best for you
      DrawingHelper.DrawRectangle(50, 300, 200, 400, Color.MidnightBlue, true);

      // TODO: Add your drawing code here

      base.Draw(gameTime);
    }

    Random random = new Random();

    public float RandomBetween(double min, double max)
    {
      return (float)(min + (float)random.NextDouble() * (max - min));
    }
  }
}

